searchNodes=[{"type":"module","title":"Soap","doc":"The SOAP client for Elixir based on HTTPoison (for send requests) and SweetXml (for XML parsing). Soap contains 5 main modules: Soap.Wsdl - Build wsdl components data map. Can parse raw wsdl file from external url or local path. Wsdl which is prepared this module are using for send requests. Soap.Request - Provides functionality for build and calling requests. Contains Request.Headers and Soap.Params submodules for build headers and build body with parameters validation respectively. This module is a wrapper over HTTPoison. It send requests and handle them. Soap.Response - Handle soap response and handle them. It provides functionality for parsing xml-like body and transform it to comfortable structure. Structure for this module returns with necessary data after send a request. Soap.Xsd - This module have same functionality as Soap.Wsdl module, but only for Xsd-files. It allows to parse xsd files from external resources or local path and convert it to map. Soap.Type - Provides a functionality for find and parse complex types from raw xsd file. It uses in library for validation parameters when we build request body. The Soap module can be used to parse WSDL files: iex&gt; Soap . init_model ( &quot;https://git.io/vNCWd&quot; , :url ) { :ok , %{ complex_types : [ ... ] , endpoint : &quot;...&quot; , messages : [ ... ] , namespaces : %{ ... } , operations : [ ... ] , schema_attributes : %{ ... } , soap_version : &quot;x.x&quot; , validation_types : %{ ... } } } And send requests: iex&gt; Soap . call ( wsdl , action , params ) { :ok , % Soap.Response { } } It's very common to use Soap in order to wrap APIs. See call/5 for more details on how to issue requests to soap services","ref":"Soap.html"},{"type":"function","title":"Soap.call/5","doc":"Send a request to the SOAP server based on the passed WSDL file, action and parameters. Returns {:ok, %Soap.Response{}} if the request is successful, {:error, reason} otherwise. Parameters wsdl : Wsdl model from Soap.init_model/2 function. action : Soap action to be called. Use Soap.operations/1 to get a list of available actions params : Parameters to build the body of a SOAP request. headers : Custom request headers. opts : HTTPoison options. Examples iex&gt; Soap . call ( wsdl , action , params ) { :ok , % Soap.Response { } }","ref":"Soap.html#call/5"},{"type":"function","title":"Soap.init_model/3","doc":"Initialization of a WSDL model. Response a map of parsed data from file. Returns {:ok, wsdl} . Parameters path : Path for wsdl file. type : Atom that represents the type of path for WSDL file. Can be :file or url . Default: :file . endpoint : Endpoint to be used for the request. Defaults to the endpoint specified in the WSDL file. Useful for (e.g.) sending a request to a mock server during testing. opts : any options for HTTPoison.Request and the following parsing options: :soap_version - Specifies SOAP version for parsing. :allow_empty_soap_actions - Allows SOAP operations with an empty soapAction attribute. This may be required for APIs that do not set a soapAction for each operation. :skip_type_imports - Prevents fetching external XSDs for importing types. Examples iex&gt; { :ok , wsdl } = Soap . init_model ( &quot;https://git.io/vNCWd&quot; , :url ) { :ok , %{ ... } }","ref":"Soap.html#init_model/3"},{"type":"function","title":"Soap.operations/1","doc":"Returns a list of available actions of the passed WSDL. Parameters wsdl : Wsdl model from Soap.init_model/2 function. Examples iex&gt; { :ok , wsdl } = Soap . init_model ( &quot;https://git.io/vNCWd&quot; , :url ) iex&gt; Soap . operations ( wsdl ) [ &quot;SendMessage&quot; , &quot;SendMessageMultipleRecipients&quot; ]","ref":"Soap.html#operations/1"},{"type":"module","title":"Soap.Request","doc":"Documentation for Soap.Request.","ref":"Soap.Request.html"},{"type":"function","title":"Soap.Request.call/5","doc":"Executing with parsed wsdl and headers with body map. Calling HTTPoison request by Map with method, url, body, headers, options keys.","ref":"Soap.Request.html#call/5"},{"type":"function","title":"Soap.Request.get_http_client/0","doc":"","ref":"Soap.Request.html#get_http_client/0"},{"type":"module","title":"Soap.Request.Headers","doc":"Headers generator by soap action and custom headers. Examples iex&gt; { :ok , wsdl } = Fixtures . get_file_path ( &quot;wsdl/SendService.wsdl&quot; ) |&gt; Soap . init_model ( :file ) ...&gt; Soap.Request.Headers . build ( wsdl , &quot;SendMessage&quot; , [ ] ) [ { &quot;SOAPAction&quot; , &quot;com.esendex.ems.soapinterface/SendMessage&quot; } , { &quot;Content-Type&quot; , &quot;text/xml;charset=utf-8&quot; } ]","ref":"Soap.Request.Headers.html"},{"type":"function","title":"Soap.Request.Headers.build/3","doc":"","ref":"Soap.Request.Headers.html#build/3"},{"type":"module","title":"Soap.Request.Params","doc":"Documentation for Soap.Request.Options.","ref":"Soap.Request.Params.html"},{"type":"function","title":"Soap.Request.Params.build_body/4","doc":"Parsing parameters map and generate body xml by given soap action name and body params(Map). Returns XML-like string.","ref":"Soap.Request.Params.html#build_body/4"},{"type":"function","title":"Soap.Request.Params.validate_params/3","doc":"","ref":"Soap.Request.Params.html#validate_params/3"},{"type":"module","title":"Soap.Response","doc":"Struct for response given by soap call.","ref":"Soap.Response.html"},{"type":"function","title":"Soap.Response.parse/1","doc":"Executing with xml response body as string. Function parse/1 returns a full parsed response structure as map.","ref":"Soap.Response.html#parse/1"},{"type":"function","title":"Soap.Response.parse/2","doc":"","ref":"Soap.Response.html#parse/2"},{"type":"type","title":"Soap.Response.t/0","doc":"","ref":"Soap.Response.html#t:t/0"},{"type":"module","title":"Soap.Response.Parser","doc":"Provides a functions for parse an XML-like response body.","ref":"Soap.Response.Parser.html"},{"type":"function","title":"Soap.Response.Parser.parse/2","doc":"Executing with XML response body. If a list is empty then parse/1 returns full parsed response structure into map.","ref":"Soap.Response.Parser.html#parse/2"},{"type":"module","title":"Soap.Type","doc":"Provides functions for parsing types to struct","ref":"Soap.Type.html"},{"type":"function","title":"Soap.Type.get_complex_types/2","doc":"","ref":"Soap.Type.html#get_complex_types/2"},{"type":"module","title":"Soap.Wsdl","doc":"Provides functions for parsing wsdl file.","ref":"Soap.Wsdl.html"},{"type":"function","title":"Soap.Wsdl.get_endpoint/3","doc":"","ref":"Soap.Wsdl.html#get_endpoint/3"},{"type":"function","title":"Soap.Wsdl.get_schema_imports/3","doc":"","ref":"Soap.Wsdl.html#get_schema_imports/3"},{"type":"function","title":"Soap.Wsdl.get_validation_types/6","doc":"","ref":"Soap.Wsdl.html#get_validation_types/6"},{"type":"function","title":"Soap.Wsdl.parse/3","doc":"","ref":"Soap.Wsdl.html#parse/3"},{"type":"function","title":"Soap.Wsdl.parse_from_file/2","doc":"","ref":"Soap.Wsdl.html#parse_from_file/2"},{"type":"function","title":"Soap.Wsdl.parse_from_url/2","doc":"","ref":"Soap.Wsdl.html#parse_from_url/2"},{"type":"module","title":"Soap.Xsd","doc":"Provides functions for parsing xsd file.","ref":"Soap.Xsd.html"},{"type":"function","title":"Soap.Xsd.parse/2","doc":"","ref":"Soap.Xsd.html#parse/2"},{"type":"function","title":"Soap.Xsd.parse_from_file/1","doc":"","ref":"Soap.Xsd.html#parse_from_file/1"},{"type":"function","title":"Soap.Xsd.parse_from_url/2","doc":"","ref":"Soap.Xsd.html#parse_from_url/2"},{"type":"exception","title":"OperationError","doc":"Defines an exception that handles not described WSDL operations.","ref":"OperationError.html"},{"type":"extras","title":"Changelog","doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html"},{"type":"extras","title":"Changelog - v1.1.1 - 2023-08-18","doc":"🚀 Features Add ability to pass arbitrary url in opts for testing [#104] Support HTTPoison 2.x [#111] 🧰 Maintenance Swap to Github Actions [#112]","ref":"changelog.html#v1-1-1-2023-08-18"},{"type":"extras","title":"Changelog - v1.1.0 - 2022-04-10","doc":"🧰 Maintenance Add tests for Elixir v1.9.4 and drop versions older than v1.9 Relax dependencies [#97] Misc doc changes [#95] Switch from deprecated Mix.Config to Config [#100] Add dialyzer and fix type specs [#93] 🚀 Features Add request options to Soap.init_model [#72] Allow blank soap actions on operations [#85] Make HTTPoison client configurable [#90] Allow string params that happen to be all digit characters [#98] Pass HTTP options to XSD and add ability to skip XSD fetching [#103] Add support for XML attributes in SOAP request bodies [#99] Parsing the document once instead of billion times [#96] 🐛 Bug Fixes Fix error in WSDL without complex types [#79] Fix load xsd files [#80] Fix parse WSDL without schema attributes [#81]","ref":"changelog.html#v1-1-0-2022-04-10"},{"type":"extras","title":"Changelog - v1.0.1 - 2019-02-14","doc":"🧰 Maintenance Improve documentation [#66]","ref":"changelog.html#v1-0-1-2019-02-14"},{"type":"extras","title":"Changelog - v1.0.0 - 2019-02-14 🎉🎉","doc":"🚀 Features Add Soap.Response.parse/1 [#61] Add xsd parsing from external resources [#57] 🐛 Bug Fixes Fix bug when namespaces is empty [#60] 🧰 Maintenance Improve readme and documentation [#64] Code improvements (dependencies, credo, formatter) [#63] Add code coverage [#62] Add more documentation and maked some functions as private [#59] Add latest major versions elixir to CI [#58]","ref":"changelog.html#v1-0-0-2019-02-14"},{"type":"extras","title":"Changelog - v0.2.1 - 2019-02-08","doc":"Fix crash in parsing by reason of incorrect expression [#56] Update library dependencies [#55]","ref":"changelog.html#v0-2-1-2019-02-08"},{"type":"extras","title":"Changelog - v0.2.0 - 2019-02-05","doc":"Add MIT license [#53] Feat/soap headers [#50] Support for different SOAP version for different WSDL files [#49] Support WSDL files with WSDL namespace being root [#46] Skip params validation if prebuilt XML given [#45]","ref":"changelog.html#v0-2-0-2019-02-05"},{"type":"extras","title":"Changelog - v0.1.2 - 2018-09-09","doc":"Update HTTPoison [#44]","ref":"changelog.html#v0-1-2-2018-09-09"},{"type":"extras","title":"Changelog - v0.1.1 - 2018-01-22","doc":"Now Soap.call/4 returns its own response structure %Soap.Response{body: nil, headers: [], request_url: nil, status_code: nil}","ref":"changelog.html#v0-1-1-2018-01-22"},{"type":"extras","title":"Changelog - v0.1.0 - 2018-01-17","doc":"Initial release. A simple low-tested wrapper for sending SOAP requests based on wsdl. Parsing base struct from WSDL. Soap.init_model/2 Parsing WSDL from file or url. List operations from WSDL. Soap.operations/1 Execution call requests Soap.call/4","ref":"changelog.html#v0-1-0-2018-01-17"},{"type":"extras","title":"License","doc":"Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"SOAP client for Elixir programming language.","ref":"readme.html"},{"type":"extras","title":"Overview - Installation","doc":"Add :soap to your deps: def deps do [ { :soap , &quot;~&gt; 1.0&quot; } ] end Add :soap to the list of application dependencies(or just use extra_applications ): def application do [ applications : [ :logger , :soap ] ] end","ref":"readme.html#installation"},{"type":"extras","title":"Overview - Configuration","doc":"Configure version of SOAP protocol. Supported versions 1.1 (default) and 1.2 : config :soap , :globals , version : &quot;1.1&quot;","ref":"readme.html#configuration"},{"type":"extras","title":"Overview - Usage","doc":"The documentation is available on HexDocs . Parse WSDL file for execution of actions on its basis: iex&gt; { :ok , wsdl } = Soap . init_model ( wsdl_path , :url ) { :ok , parsed_wsdl } Get list of available operations: iex&gt; Soap . operations ( wsdl ) [ %{ input : %{ body : nil , header : nil } , name : &quot;Add&quot; , soap_action : &quot;http://tempuri.org/Add&quot; } , %{ input : %{ body : nil , header : nil } , name : &quot;Subtract&quot; , soap_action : &quot;http://tempuri.org/Subtract&quot; } , %{ input : %{ body : nil , header : nil } , name : &quot;Multiply&quot; , soap_action : &quot;http://tempuri.org/Multiply&quot; } , %{ input : %{ body : nil , header : nil } , name : &quot;Divide&quot; , soap_action : &quot;http://tempuri.org/Divide&quot; } ] Call action: wsdl_path = &quot;http://www.dneonline.com/calculator.asmx?WSDL&quot; action = &quot;Add&quot; params = %{ intA : 1 , intB : 2 } iex&gt; { :ok , response } = Soap . call ( wsdl , action , params ) { :ok , % Soap.Response { body : &quot;&lt;?xml version= \\&quot; 1.0 \\&quot; encoding= \\&quot; utf-8 \\&quot; ?&gt;&lt;soap:Envelope xmlns:soap= \\&quot; http://schemas.xmlsoap.org/soap/envelope/ \\&quot; xmlns:xsi= \\&quot; http://www.w3.org/2001/XMLSchema-instance \\&quot; xmlns:xsd= \\&quot; http://www.w3.org/2001/XMLSchema \\&quot; &gt;&lt;soap:Body&gt;&lt;AddResponse xmlns= \\&quot; http://tempuri.org/ \\&quot; &gt;&lt;AddResult&gt;3&lt;/AddResult&gt;&lt;/AddResponse&gt;&lt;/soap:Body&gt;&lt;/soap:Envelope&gt;&quot; , headers : [ { &quot;Cache-Control&quot; , &quot;private, max-age=0&quot; } , { &quot;Content-Length&quot; , &quot;325&quot; } , { &quot;Content-Type&quot; , &quot;text/xml; charset=utf-8&quot; } , { &quot;Server&quot; , &quot;Microsoft-IIS/7.5&quot; } , { &quot;X-AspNet-Version&quot; , &quot;2.0.50727&quot; } , { &quot;X-Powered-By&quot; , &quot;ASP.NET&quot; } , { &quot;Date&quot; , &quot;Thu, 14 Feb 2019 07:52:04 GMT&quot; } ] , request_url : &quot;http://www.dneonline.com/calculator.asmx&quot; , status_code : 200 } } Parse response: iex&gt; Soap.Response . parse ( response ) %{ AddResponse : %{ AddResult : &quot;3&quot; } } To add SOAP headers, pass in a {headers, params} tuple instead of just params: { :ok , % Soap.Response { } } = Soap . call ( wsdl , action , { %{ Token : &quot;foo&quot; } , params } )","ref":"readme.html#usage"},{"type":"extras","title":"Overview - Contributing","doc":"We appreciate any contribution and open to future requests . You can find a list of features and bugs in the issue tracker .","ref":"readme.html#contributing"},{"type":"extras","title":"Overview - Copyright and License","doc":"Copyright (c) 2017 Petr Stepchenko This work is free. You can redistribute it and/or modify it under the terms of the MIT License. See the LICENSE.md file for more details.","ref":"readme.html#copyright-and-license"}]